import os
import sipconfig

# The name of the SIP build file generated by SIP and used by the build
# system.
build_file = "ftgl.sbf"

# Get the SIP configuration information.
config = sipconfig.Configuration()

# Run SIP to generate the code.
os.system(" ".join([config.sip_bin, "-c", ".", "-b", build_file, 
                    "ftgl.sip"]))

# Create the Makefile.
makefile = sipconfig.SIPModuleMakefile(config, build_file)

# Add the library we are wrapping.  The name doesn't include any platform
# specific prefixes or extensions (e.g. the "lib" prefix on UNIX, or the
# ".dll" extension on Windows).
makefile.extra_libs = ["ftgl"]


makefile.extra_lflags = [
    # this should be set to where libftgl lies
    "-L/usr/local/lib"
]

makefile.extra_include_dirs = [
    # this should be set to where your FTGL header directory lies
    "/usr/local/include", 
    # this should be set to where your freetype header directory lies
    "/usr/local/include/freetype2"]

# Generate the Makefile itself.
makefile.generate()



from setuptools import setup, Extension, find_packages

import sipdistutils

setup(
    name='sippy-ftgl',
    version='0.1.0',
    ext_modules=[
        Extension('FTGL', 
                  ['ftgl.sip'],
                  library_dirs=['/usr/local/lib'],
                  libraries=['ftgl']),
    ],
    include_dirs=['.', '/usr/local/include', '/usr/local/include/freetype2'],
    cmdclass = {'build_ext':sipdistutils.build_ext},

    # metadata for upload to PyPI
    author = "michael j pan",
    author_email = "mikepan@gmail.com",
    description = "Python binding for FTGL using SIP",
    license = "New BSD",
    keywords = "ftgl SIP",
    url = "http://code.google.com/p/sippy-ftgl/",
    long_description = "This is a Python binding for FTGL using SIP",
    platforms = ["All"]

)

